===============================
safety
===============================


.. image:: https://img.shields.io/pypi/v/safety.svg
        :target: https://pypi.python.org/pypi/safety

.. image:: https://img.shields.io/travis/pyupio/safety.svg
        :target: https://travis-ci.org/pyupio/safety

.. image:: https://readthedocs.org/projects/safety/badge/?version=latest
        :target: https://safety.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/pyupio/safety/shield.svg
     :target: https://pyup.io/repos/github/pyupio/safety/
     :alt: Updates


Python Boilerplate contains all the boilerplate you need to create a Python package.


* Free software: MIT license
* Documentation: https://safety.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

